|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r50945 - trunk/boost/asio/detail
From: chris_at_[hidden]
Date: 2009-02-01 06:57:01
Author: chris_kohlhoff
Date: 2009-02-01 06:57:01 EST (Sun, 01 Feb 2009)
New Revision: 50945
URL: http://svn.boost.org/trac/boost/changeset/50945
Log:
Improve warning message when _WIN32_WINNT is not correctly defined. Fixes #2541.
Text files modified:
trunk/boost/asio/detail/socket_types.hpp | 12 ++++++++----
1 files changed, 8 insertions(+), 4 deletions(-)
Modified: trunk/boost/asio/detail/socket_types.hpp
==============================================================================
--- trunk/boost/asio/detail/socket_types.hpp (original)
+++ trunk/boost/asio/detail/socket_types.hpp 2009-02-01 06:57:01 EST (Sun, 01 Feb 2009)
@@ -28,11 +28,15 @@
# endif // defined(_WINSOCKAPI_) && !defined(_WINSOCK2API_)
# if !defined(_WIN32_WINNT) && !defined(_WIN32_WINDOWS)
# if defined(_MSC_VER) || defined(__BORLANDC__)
-# pragma message("Please define _WIN32_WINNT or _WIN32_WINDOWS appropriately")
-# pragma message("Assuming _WIN32_WINNT=0x0501 (i.e. Windows XP target)")
+# pragma message( \
+ "Please define _WIN32_WINNT or _WIN32_WINDOWS appropriately. For example:\n"\
+ "- add -D_WIN32_WINNT=0x0501 to the compiler command line; or\n"\
+ "- add _WIN32_WINNT=0x0501 to your project's Preprocessor Definitions.\n"\
+ "Assuming _WIN32_WINNT=0x0501 (i.e. Windows XP target).")
# else // defined(_MSC_VER) || defined(__BORLANDC__)
# warning Please define _WIN32_WINNT or _WIN32_WINDOWS appropriately
# warning Assuming _WIN32_WINNT=0x0501 (i.e. Windows XP target)
# endif // defined(_MSC_VER) || defined(__BORLANDC__)
# define _WIN32_WINNT 0x0501
# endif // !defined(_WIN32_WINNT) && !defined(_WIN32_WINDOWS)
@@ -28,11 +28,15 @@
# else // defined(_MSC_VER) || defined(__BORLANDC__)
-# warning Please define _WIN32_WINNT or _WIN32_WINDOWS appropriately
-# warning Assuming _WIN32_WINNT=0x0501 (i.e. Windows XP target)
+# warning Please define _WIN32_WINNT or _WIN32_WINDOWS appropriately.
+# warning For example, add -D_WIN32_WINNT=0x0501 to the compiler command line.
+# warning Assuming _WIN32_WINNT=0x0501 (i.e. Windows XP target).
# endif // defined(_MSC_VER) || defined(__BORLANDC__)
# define _WIN32_WINNT 0x0501
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk